@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU Lesser General
  * Public License along with this library; if not, see
- * <http://www.gnu.org/licenses/>.
+ * <https://www.gnu.org/licenses/>.
  */
 
 #define BABL_DYNAMIC_EXTENSIONS
@@ -31,9 +31,11 @@
 #include "babl-internal.h"
 #include "babl-db.h"
 #include "babl-base.h"
+
 #include <string.h>
 #include <stdarg.h>
 
+
 static Babl *babl_extension_current_extender = NULL;
 
 Babl *
@@ -107,14 +109,17 @@ babl_extension_base (void)
     if (ret != babl)
       babl_free (babl);
     else
+    {
       babl_base_init ();
+    }
     babl = ret;
   }
   babl_set_extender (NULL);
   return babl;
 }
 
-void babl_extension_deinit (void)
+void 
+babl_extension_deinit (void)
 {
   babl_free (babl_quiet);
   babl_quiet = NULL;
@@ -145,12 +150,16 @@ void babl_extension_deinit (void)
 #if !defined(BIND_RESTRICTED)
 #  define BIND_RESTRICTED       0
 #endif
-#define RTLD_NOW		(BIND_IMMEDIATE|BIND_NONFATAL|DYNAMIC_PATH)
+#define RTLD_NOW              (BIND_IMMEDIATE|BIND_NONFATAL|DYNAMIC_PATH)
 #define HLIB   shl_t
 #define dlopen(path, flags)    shl_load (path, flags, 0L)
 #define dlclose(handle)                shl_unload (handle)
 #define dlerror()              strerror (errno)
-static void *dlsym (HLIB handle, const char *name) {
+
+static void *
+dlsym (HLIB        handle, 
+       const char *name) 
+{
   void *address = 0;
   shl_findsym(&handle, name, TYPE_UNDEFINED, &address);
   return address;
@@ -238,7 +247,8 @@ babl_extension_load (const char *path)
 }
 
 static void
-babl_extension_load_dir (const char *base_path)
+babl_extension_load_dir (const char *base_path,
+                         const char **exclusion_patterns)
 {
   DIR *dir;
 
@@ -251,19 +261,21 @@ babl_extension_load_dir (const char *base_path)
           if (dentry->d_name[0] != '.')
             {
               char       *path = NULL;
-              struct stat st;
               char       *extension;
 
               path = babl_strcat (path, base_path);
               path = babl_strcat (path, BABL_DIR_SEPARATOR);
               path = babl_strcat (path, dentry->d_name);
 
-              stat (path, &st);
-
               if ((extension = strrchr (dentry->d_name, '.')) != NULL &&
                   !strcmp (extension, SHREXT))
                 {
-                  babl_extension_load (path);
+                  int excluded = 0;
+                  for (int i = 0; exclusion_patterns[i]; i++)
+                    if (strstr (path, exclusion_patterns[i]))
+                      excluded = 1;
+                  if (!excluded)
+                    babl_extension_load (path);
                 }
 
               babl_free (path);
@@ -310,7 +322,8 @@ expand_path (char *path)
 /*  parse the provided colon seperated list of paths to search
  */
 void
-babl_extension_load_dir_list (const char *dir_list)
+babl_extension_load_dir_list (const char *dir_list,
+                              const char **exclusion_patterns)
 {
   int         eos = 0;
   const char *src;
@@ -332,8 +345,10 @@ babl_extension_load_dir_list (const char *dir_list)
           case BABL_PATH_SEPARATOR:
           {
             char *expanded_path = expand_path (path);
-            babl_extension_load_dir (expanded_path);
-            babl_free (expanded_path);
+            if (expanded_path) {
+                babl_extension_load_dir (expanded_path, exclusion_patterns);
+                babl_free (expanded_path);
+            }
           }
             dst = path;
             src++;
@@ -347,6 +362,13 @@ babl_extension_load_dir_list (const char *dir_list)
         }
     }
   babl_free (path);
+  if (babl_db_count (db) <= 1)
+  {
+    babl_log ("WARNING: the babl installation seems broken, no extensions found in queried\n"
+              "BABL_PATH (%s) this means no SIMD/instructions/special case fast paths and\n"
+              "only slow reference conversions are available, applications might still\n"
+              "run but software relying on babl for conversions will be slow\n", dir_list);
+  }
 }
 
 #endif
