@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU Lesser General
  * Public License along with this library; if not, see
- * <http://www.gnu.org/licenses/>.
+ * <https://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -59,9 +59,9 @@ test (void)
 
   for (i = 0; i < PIXELS * 3; i++)
     {
-      if (rgb_buf[i] != rgb_buf_ref[i])
+      if (fabs (rgb_buf[i] - rgb_buf_ref[i]) > 0.0000001)
         {
-          babl_log ("index %i is problematic : %f instead of %f",
+          babl_log ("index %i is problematic : %.12f instead of %.12f",
                     i, rgb_buf[i], rgb_buf_ref[i]);
           OK = 0;
         }
